@@ -1,7 +1,6 @@
 #!/bin/bash
 
 set -e
-set -x
 
 ###################
 ####>> TOOLS <<####
@@ -318,6 +317,10 @@ function alis_install_package() {
           ALL_PACKAGES+=(teamviewer)
           ALL_CONFIG+=(teamviewer_system)
           ;;
+        imwheel)
+          ALL_PACKAGES+=(imwheel)
+          ALL_CONFIG+=(imwheel_user)
+          ;;
         util-packages)
           collect_configs nano zip unzip wget bash-completion openssh seahorse networkmanager-fortisslvpn
           ;;
@@ -629,6 +632,37 @@ EOT
     systemctl start teamviewerd.service
   }
 
+  function imwheel_user() {
+    cat <<'EOT' >~/.imwheelrc
+"^.*$"
+    None, Up, Button4, 3.5
+    None, Down, Button5, 3.5
+EOT
+
+    mkdir -p ~/.config/autostart
+    cat <<'EOT' >~/.config/autostart/imwheel.desktop
+[Desktop Entry]
+Comment[en_US]=
+Comment=
+Exec=/usr/bin/imwheel -b 45
+GenericName[en_US]=
+GenericName=
+Icon=system-run
+MimeType=
+Name[en_US]=imwheel
+Name=imwheel
+Path=
+StartupNotify=true
+Terminal=false
+TerminalOptions=
+Type=Application
+X-DBUS-ServiceName=
+X-DBUS-StartupType=
+X-KDE-SubstituteUID=false
+X-KDE-Username=
+EOT
+  }
+
   ARGUMENTS=$(printf '%q ' "${*:2}")
   eval "$1" "$ARGUMENTS"
 }
